@@ -17,12 +17,12 @@
 
 import logging
 
+from novaclient import api_versions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
-from openstackclient.i18n import _LE
 
 
 LOG = logging.getLogger(__name__)
@@ -143,7 +143,7 @@ class SetService(command.Command):
             "--disable-reason",
             default=None,
             metavar="<reason>",
-            help=_("Reason for disabling the service (in quotas). "
+            help=_("Reason for disabling the service (in quotes). "
                    "Should be used with --disable option.")
         )
         up_down_group = parser.add_mutually_exclusive_group()
@@ -189,22 +189,27 @@ class SetService(command.Command):
                         cs.disable(parsed_args.host, parsed_args.service)
         except Exception:
             status = "enabled" if enabled else "disabled"
-            LOG.error(_LE("Failed to set service status to %s"), status)
+            LOG.error("Failed to set service status to %s", status)
             result += 1
 
         force_down = None
-        try:
-            if parsed_args.down:
-                force_down = True
-            if parsed_args.up:
-                force_down = False
-            if force_down is not None:
+        if parsed_args.down:
+            force_down = True
+        if parsed_args.up:
+            force_down = False
+        if force_down is not None:
+            if compute_client.api_version < api_versions.APIVersion(
+                    '2.11'):
+                msg = _('--os-compute-api-version 2.11 or later is '
+                        'required')
+                raise exceptions.CommandError(msg)
+            try:
                 cs.force_down(parsed_args.host, parsed_args.service,
                               force_down=force_down)
-        except Exception:
-            state = "down" if force_down else "up"
-            LOG.error(_LE("Failed to set service state to %s"), state)
-            result += 1
+            except Exception:
+                state = "down" if force_down else "up"
+                LOG.error("Failed to set service state to %s", state)
+                result += 1
 
         if result > 0:
             msg = _("Compute service %(service)s of host %(host)s failed to "
