@@ -26,6 +26,16 @@ from osc_lib import utils
 from openstackclient.i18n import _
 
 
+def find_service_in_list(service_list, service_id):
+    """Find a service by id in service list."""
+
+    for service in service_list:
+        if service.id == service_id:
+            return service
+    raise exceptions.CommandError(
+        "No service with a type, name or ID of '%s' exists." % service_id)
+
+
 def find_service(identity_client, name_type_or_id):
     """Find a service by id, name or type."""
 
@@ -91,6 +101,13 @@ def _get_token_resource(client, resource, parsed_name, parsed_domain=None):
         # user/project under different domain may has a same name
         if parsed_domain and parsed_domain not in obj['domain'].values():
             return parsed_name
+        if isinstance(obj, list):
+            for item in obj:
+                if item['name'] == parsed_name:
+                    return item['id']
+                if item['id'] == parsed_name:
+                    return parsed_name
+            return parsed_name
         return obj['id'] if obj['name'] == parsed_name else parsed_name
     # diaper defense in case parsing the token fails
     except Exception:  # noqa
