@@ -13,8 +13,6 @@
 
 """IP Floating action implementations"""
 
-import logging
-
 from osc_lib.command import command
 from osc_lib import utils
 
@@ -22,6 +20,12 @@ from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
 from openstackclient.network import sdk_utils
+from openstackclient.network.v2 import _tag
+
+
+_formatters = {
+    'port_details': utils.format_dict,
+}
 
 
 def _get_network_columns(item):
@@ -139,11 +143,14 @@ class CreateFloatingIP(common.NetworkAndComputeShowOne):
             help=_("Owner's project (name or ID)")
         )
         identity_common.add_project_domain_option_to_parser(parser)
+        _tag.add_tag_option_to_parser_for_create(parser, _('floating IP'))
         return parser
 
     def take_action_network(self, client, parsed_args):
         attrs = _get_attrs(self.app.client_manager, parsed_args)
         obj = client.create_ip(**attrs)
+        # tags cannot be set when created, so tags need to be set later.
+        _tag.update_tags_for_set(client, obj, parsed_args)
         display_columns, columns = _get_network_columns(obj)
         data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
@@ -155,30 +162,6 @@ class CreateFloatingIP(common.NetworkAndComputeShowOne):
         return (columns, data)
 
 
-class CreateIPFloating(CreateFloatingIP):
-    _description = _("Create floating IP")
-
-    # TODO(tangchen): Remove this class and ``ip floating create`` command
-    #                 two cycles after Mitaka.
-
-    # This notifies cliff to not display the help for this command
-    deprecated = True
-
-    log = logging.getLogger('deprecated')
-
-    def take_action_network(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip create" instead.'))
-        return super(CreateIPFloating, self).take_action_network(
-            client, parsed_args)
-
-    def take_action_compute(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip create" instead.'))
-        return super(CreateIPFloating, self).take_action_compute(
-            client, parsed_args)
-
-
 class DeleteFloatingIP(common.NetworkAndComputeDelete):
     _description = _("Delete floating IP(s)")
 
@@ -206,30 +189,6 @@ class DeleteFloatingIP(common.NetworkAndComputeDelete):
         client.api.floating_ip_delete(self.r)
 
 
-class DeleteIPFloating(DeleteFloatingIP):
-    _description = _("Delete floating IP(s)")
-
-    # TODO(tangchen): Remove this class and ``ip floating delete`` command
-    #                 two cycles after Mitaka.
-
-    # This notifies cliff to not display the help for this command
-    deprecated = True
-
-    log = logging.getLogger('deprecated')
-
-    def take_action_network(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip delete" instead.'))
-        return super(DeleteIPFloating, self).take_action_network(
-            client, parsed_args)
-
-    def take_action_compute(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip delete" instead.'))
-        return super(DeleteIPFloating, self).take_action_compute(
-            client, parsed_args)
-
-
 class ListFloatingIP(common.NetworkAndComputeLister):
     # TODO(songminglong): Use SDK resource mapped attribute names once
     # the OSC minimum requirements include SDK 1.0
@@ -280,6 +239,7 @@ class ListFloatingIP(common.NetworkAndComputeLister):
             help=_("List floating IP(s) according to "
                    "given router (name or ID)")
         )
+        _tag.add_tag_filtering_option_to_parser(parser, _('floating IP'))
 
         return parser
 
@@ -308,11 +268,13 @@ class ListFloatingIP(common.NetworkAndComputeLister):
                 'router_id',
                 'status',
                 'description',
+                'tags',
             )
             headers = headers + (
                 'Router',
                 'Status',
                 'Description',
+                'Tags',
             )
 
         query = {}
@@ -342,6 +304,8 @@ class ListFloatingIP(common.NetworkAndComputeLister):
                                                 ignore_missing=False)
             query['router_id'] = router.id
 
+        _tag.get_tag_filtering_args(parsed_args, query)
+
         data = client.ips(**query)
 
         return (headers,
@@ -375,30 +339,6 @@ class ListFloatingIP(common.NetworkAndComputeLister):
                 ) for s in data))
 
 
-class ListIPFloating(ListFloatingIP):
-    _description = _("List floating IP(s)")
-
-    # TODO(tangchen): Remove this class and ``ip floating list`` command
-    #                 two cycles after Mitaka.
-
-    # This notifies cliff to not display the help for this command
-    deprecated = True
-
-    log = logging.getLogger('deprecated')
-
-    def take_action_network(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip list" instead.'))
-        return super(ListIPFloating, self).take_action_network(
-            client, parsed_args)
-
-    def take_action_compute(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip list" instead.'))
-        return super(ListIPFloating, self).take_action_compute(
-            client, parsed_args)
-
-
 class SetFloatingIP(command.Command):
     _description = _("Set floating IP Properties")
 
@@ -407,11 +347,10 @@ class SetFloatingIP(command.Command):
         parser.add_argument(
             'floating_ip',
             metavar='<floating-ip>',
-            help=_("Floating IP to associate (IP address or ID)"))
+            help=_("Floating IP to modify (IP address or ID)"))
         parser.add_argument(
             '--port',
             metavar='<port>',
-            required=True,
             help=_("Associate the floating IP with port (name or ID)")),
         parser.add_argument(
             '--fixed-ip-address',
@@ -431,6 +370,9 @@ class SetFloatingIP(command.Command):
             action='store_true',
             help=_("Remove the QoS policy attached to the floating IP")
         )
+
+        _tag.add_tag_option_to_parser_for_set(parser, _('floating IP'))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -440,9 +382,11 @@ class SetFloatingIP(command.Command):
             parsed_args.floating_ip,
             ignore_missing=False,
         )
-        port = client.find_port(parsed_args.port,
-                                ignore_missing=False)
-        attrs['port_id'] = port.id
+        if parsed_args.port:
+            port = client.find_port(parsed_args.port,
+                                    ignore_missing=False)
+            attrs['port_id'] = port.id
+
         if parsed_args.fixed_ip_address:
             attrs['fixed_ip_address'] = parsed_args.fixed_ip_address
 
@@ -453,7 +397,11 @@ class SetFloatingIP(command.Command):
         if 'no_qos_policy' in parsed_args and parsed_args.no_qos_policy:
             attrs['qos_policy_id'] = None
 
-        client.update_ip(obj, **attrs)
+        if attrs:
+            client.update_ip(obj, **attrs)
+
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_set(client, obj, parsed_args)
 
 
 class ShowFloatingIP(common.NetworkAndComputeShowOne):
@@ -473,7 +421,7 @@ class ShowFloatingIP(common.NetworkAndComputeShowOne):
             ignore_missing=False,
         )
         display_columns, columns = _get_network_columns(obj)
-        data = utils.get_item_properties(obj, columns)
+        data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
@@ -483,30 +431,6 @@ class ShowFloatingIP(common.NetworkAndComputeShowOne):
         return (columns, data)
 
 
-class ShowIPFloating(ShowFloatingIP):
-    _description = _("Display floating IP details")
-
-    # TODO(tangchen): Remove this class and ``ip floating show`` command
-    #                 two cycles after Mitaka.
-
-    # This notifies cliff to not display the help for this command
-    deprecated = True
-
-    log = logging.getLogger('deprecated')
-
-    def take_action_network(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip show" instead.'))
-        return super(ShowIPFloating, self).take_action_network(
-            client, parsed_args)
-
-    def take_action_compute(self, client, parsed_args):
-        self.log.warning(_('This command has been deprecated. '
-                           'Please use "floating ip show" instead.'))
-        return super(ShowIPFloating, self).take_action_compute(
-            client, parsed_args)
-
-
 class UnsetFloatingIP(command.Command):
     _description = _("Unset floating IP Properties")
 
@@ -528,6 +452,8 @@ class UnsetFloatingIP(command.Command):
             default=False,
             help=_("Remove the QoS policy attached to the floating IP")
         )
+        _tag.add_tag_option_to_parser_for_unset(parser, _('floating IP'))
+
         return parser
 
     def take_action(self, parsed_args):
@@ -544,3 +470,6 @@ class UnsetFloatingIP(command.Command):
 
         if attrs:
             client.update_ip(obj, **attrs)
+
+        # tags is a subresource and it needs to be updated separately.
+        _tag.update_tags_for_unset(client, obj, parsed_args)
